<?php
/**
 * @package: phpBB 3.0.10 :: AOS Notifications -> root/includes/acp/
 * @version: $Id: acp_aos_notifications.php, v 0.0.8 2012/03/06 15:56:42 Alorse Exp $
 * @copyright: Alorse <> (Fredo) http://phpbb.alorse.net/
 * @license: http://opensource.org/licenses/gpl-license.php GNU Public License
 * @author: Alorse - http://www.phpbb.com/customise/db/author/alorse/
 * 
 */
/**
 * @ignore
 */
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
 * @package acp
 */
class acp_aos_notifications
{

	var $action;

	function main($id, $mode)
	{
		global $user, $template, $config;

		$user->add_lang('mods/info_acp_aos_notifications');
		$this->tpl_name = 'acp_board';
		$this->page_title = 'AOS_NOTIFICATIONS';

		// Variables del módulo
		$submit = request_var('submit', '', true) ? true : false;

		switch ($mode)
		{
			case 'settings':
				$display_vars = array(
					'title' => 'AOS_NOTIFICATIONS',
					'vars' => array(
						'legend1' => 'AOS_N_INDEX',
						'aos_n_version' => array('lang' => 'AOS_N_VERSION', 'validate' => 'string', 'type' => 'custom', 'method' => 'aos_n_version', 'explain' => false),
						'aos_n_enable' => array('lang' => 'AOS_N_ENABLE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
						'aos_n_viewprofile' => array('lang' => 'AOS_N_VIEWPROFILE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true),
						'aos_n_vmn' => array('lang' => 'AOS_N_VIEW_MORE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true),
						'legend2' => 'ACP_SUBMIT_CHANGES',
					)
				);
				break;

			default:
				trigger_error('NO_MODE', E_USER_ERROR);
				break;
		}

		$this->new_config = $config;
		$cfg_array = (isset($_REQUEST['config'])) ? utf8_normalize_nfc(request_var('config', array('' => ''), true)) : $this->new_config;
		$error = array();

		// We validate the complete config if whished
		validate_config_vars($display_vars['vars'], $cfg_array, $error);


		// We go through the display_vars to make sure no one is trying to set variables he/she is not allowed to...
		foreach ($display_vars['vars'] as $config_name => $null)
		{
			if (!isset($cfg_array[$config_name]) || strpos($config_name, 'legend') !== false)
			{
				continue;
			}

			if ($config_name == 'auth_method' || $config_name == 'feed_news_id' || $config_name == 'feed_exclude_id')
			{
				continue;
			}

			$this->new_config[$config_name] = $config_value = $cfg_array[$config_name];

			if ($config_name == 'email_function_name')
			{
				$this->new_config['email_function_name'] = trim(str_replace(array('(', ')'), array('', ''), $this->new_config['email_function_name']));
				$this->new_config['email_function_name'] = (empty($this->new_config['email_function_name']) || !function_exists($this->new_config['email_function_name'])) ? 'mail' : $this->new_config['email_function_name'];
				$config_value = $this->new_config['email_function_name'];
			}

			if ($submit)
			{
				set_config($config_name, $config_value);

				if ($config_name == 'allow_quick_reply' && isset($_POST['allow_quick_reply_enable']))
				{
					enable_bitfield_column_flag(FORUMS_TABLE, 'forum_flags', log(FORUM_FLAG_QUICK_REPLY, 2));
				}
			}
		}

		if ($submit)
		{
			add_log('admin', 'LOG_CONFIG_' . strtoupper($mode));

			trigger_error($user->lang['CONFIG_UPDATED'] . adm_back_link($this->u_action));
		}

		$this->tpl_name = 'acp_board';
		$this->page_title = $display_vars['title'];

		$template->assign_vars(array(
			'L_TITLE' => $user->lang[$display_vars['title']],
			'L_TITLE_EXPLAIN' => $user->lang[$display_vars['title'] . '_EXPLAIN'],
			'S_ERROR' => (sizeof($error)) ? true : false,
			'ERROR_MSG' => implode('<br />', $error),
			'U_ACTION' => $this->u_action)
		);

		// Output relevant page
		foreach ($display_vars['vars'] as $config_key => $vars)
		{
			if (!is_array($vars) && strpos($config_key, 'legend') === false)
			{
				continue;
			}

			if (strpos($config_key, 'legend') !== false)
			{
				$template->assign_block_vars('options', array(
					'S_LEGEND' => true,
					'LEGEND' => (isset($user->lang[$vars])) ? $user->lang[$vars] : $vars)
				);

				continue;
			}

			$type = explode(':', $vars['type']);

			$l_explain = '';
			if ($vars['explain'] && isset($vars['lang_explain']))
			{
				$l_explain = (isset($user->lang[$vars['lang_explain']])) ? $user->lang[$vars['lang_explain']] : $vars['lang_explain'];
			}
			else if ($vars['explain'])
			{
				$l_explain = (isset($user->lang[$vars['lang'] . '_EXPLAIN'])) ? $user->lang[$vars['lang'] . '_EXPLAIN'] : '';
			}

			$content = build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars);

			if (empty($content))
			{
				continue;
			}

			$template->assign_block_vars('options', array(
				'KEY' => $config_key,
				'TITLE' => (isset($user->lang[$vars['lang']])) ? $user->lang[$vars['lang']] : $vars['lang'],
				'S_EXPLAIN' => $vars['explain'],
				'TITLE_EXPLAIN' => $l_explain,
				'CONTENT' => $content,
				)
			);

			unset($display_vars['vars'][$config_key]);
		}
	}

	/**
	 * @description: Version of the database.
	 *
	 * @return String
	 *
	 * @version: 0.0.8
	 * */
	function aos_n_version()
	{
		global $config;

		return $config['aos_notifications_version'];
	}

}

?>